aboutsummaryrefslogtreecommitdiff
path: root/gdb/symtab.h
diff options
context:
space:
mode:
authorPedro Alves <palves@redhat.com>2007-03-28 00:12:15 +0000
committerPedro Alves <palves@redhat.com>2007-03-28 00:12:15 +0000
commit53c5240fe15861d08db96684b1a06c4b4ecb1958 (patch)
tree3689a982a618345c2724fc025402f7d23d409f14 /gdb/symtab.h
parent513766ac8b65196a873d98c134ba1b5ca90f28cf (diff)
downloadgdb-53c5240fe15861d08db96684b1a06c4b4ecb1958.zip
gdb-53c5240fe15861d08db96684b1a06c4b4ecb1958.tar.gz
gdb-53c5240fe15861d08db96684b1a06c4b4ecb1958.tar.bz2
* linespec.c: Include language.h.
(find_methods): Add language parameter. Call lookup_symbol_in_language. Pass language down. (add_matching_methods): Likewise. Call lookup_symbol_in_language. (add_constructors): Likewise. (find_method): Pass sym_class to collect_methods. (collect_methods): Add sym_class parameter. Pass language down. * symtab.c (lookup_symbol): Rename to ... (lookup_symbol_in_language): ... this. Add language parameter. Use passed language instead of current_language. (lookup_symbol): New as wrapper around lookup_symbol_in_language. (lookup_symbol_aux): Add language parameter. Use passed language instead of current_language. (search_symbols): Indent. * symtab.h (enum language): Forward declare. (lookup_symbol_in_language): Declare. (lookup_symbol): Update description. * ada-lang.h (lookup_symbol_in_language): Remove declaration. * ada-lang.c (restore_language): Remove. (lookup_symbol_in_language): Remove.
Diffstat (limited to 'gdb/symtab.h')
-rw-r--r--gdb/symtab.h13
1 files changed, 12 insertions, 1 deletions
diff --git a/gdb/symtab.h b/gdb/symtab.h
index da637cb..cefb0ad 100644
--- a/gdb/symtab.h
+++ b/gdb/symtab.h
@@ -34,6 +34,7 @@ struct block;
struct blockvector;
struct axs_value;
struct agent_expr;
+enum language;
/* Some of the structures in this file are space critical.
The space-critical structures are:
@@ -1007,7 +1008,17 @@ extern int asm_demangle;
extern struct symtab *lookup_symtab (const char *);
-/* lookup a symbol by name (optional block, optional symtab) */
+/* lookup a symbol by name (optional block, optional symtab) in language */
+
+extern struct symbol *lookup_symbol_in_language (const char *,
+ const struct block *,
+ const domain_enum,
+ enum language,
+ int *,
+ struct symtab **);
+
+/* lookup a symbol by name (optional block, optional symtab)
+ in the current language */
extern struct symbol *lookup_symbol (const char *, const struct block *,
const domain_enum, int *,